##
##  cvsd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2012 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         cvsd
Summary:      CVS PServer Daemon
URL:          http://arthurdejong.org/cvsd/
Vendor:       Arthur de Jong
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        SCM
License:      GPL
Version:      1.0.24
Release:      20120603

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      http://arthurdejong.org/cvsd/cvsd-%{version}.tar.gz
Source1:      cvsd.conf
Source2:      rc.cvsd
Source3:      fsl.cvsd
Patch0:       cvsd.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, cvs, gcc
PreReq:       OpenPKG, openpkg >= 20100101, cvs
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif

%description
    cvsd is a wrapper program for cvs in pserver mode. It will run
    'cvs pserver' under a special uid/gid in a chroot jail. cvsd is
    run as a daemon and is controlled through a configuration file. It
    is relatively easy to configure and tools are provided for setting
    up a rootjail. This server can be useful if you want to run a
    public cvs pserver. You should however be aware of the security
    limitations of running a cvs pserver. If you want any kind of
    authentication you should really consider using secure shell as a
    secure authentication mechanism and transport. Passwords used in cvs
    pserver are transmitted in plaintext and this wrapper won't change
    that. This server adds a layer of security to cvs. cvs is a very
    powerful tool and is capable of running scripts and other things.
    By running cvs in a rootjail it is possible to limit the amount of
    "damage" cvs can do if it is exploited. It is generally a good idea
    to run cvsd without any write permissions to any directory on the
    system.

%track
    prog cvsd = {
        version   = %{version}
        url       = http://arthurdejong.org/cvsd/downloads.html
        regex     = cvsd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    LDFLAGS="%{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix}

    #   build program
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/cvsd \
        $RPM_BUILD_ROOT%{l_prefix}/etc/cvsd

    #   perform standard installation procedure
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/etc/init.d
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   creating configuration
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE cvsd.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/cvsd/cvsd.conf

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.cvsd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.cvsd} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.cvsd'

%files -f files

%clean

%pre
    #   before upgrade, save status and stop service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} cvsd status 2>/dev/null | tee %{l_tmpfile}`
    %{l_rc} cvsd stop 2>/dev/null
    exit 0

%post
    [ $1 -eq 2 ] || exit 0
    #   after upgrade, restore status
    eval `cat %{l_tmpfile}`; rm -f %{l_tmpfile}
    [ ".$cvsd_active" = .yes ] && %{l_rc} cvsd start
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} cvsd stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/cvsd/*.log* >/dev/null 2>&1 || true
    exit 0

